from django import template
from django.utils.safestring import mark_safe
from datetime import datetime, timedelta
import operator

register=template.Library()

@register.filter
def in_group(user, group):
    """Returns True/False if the user is in any of the given group(s).

    Usage::
        {% if user|in_group:"Friends" %}
    or
        {% if user|in_group:"Friends,Enemies" %}
        ...
        {% endif %}

    You can specify a single group or a comma-delimited list.
    Users are always considered to be in group "all".
    Note that white space chars in the group argument are treated as part of
    the group names.
    """
    if group == "all":
        return True

    group_list = group.split(',')

    if not hasattr(user, '_cached_groups'):
        user._cached_groups = user.groups.all()

    return any(operator.contains(group_list, g.name) for g in user._cached_groups)

in_group.is_safe = True

@register.filter
def indent_subsequent_lines(value, indent):
    indentation = ' ' * int(indent)
    if isinstance(value, basestring):
        value = value.replace('\n', '\n' + indentation).rstrip()
    return value

@register.filter
def underline(value, char):
    if not isinstance(value, basestring):
        value = unicode(value)
    line = char * len(value)
    return value + '\n' + line

@register.filter(name='HHHHhMM')
def timedelta_format(value):
    assert type(value) == timedelta, 'This Filter only works with timedelta objects'
    seconds = value.total_seconds()
    hours, remain = divmod(abs(seconds), 3600)
    return mark_safe("%s%.0fh%02.0f" % ("-" if seconds < 0 else "", hours, remain/60))

@register.filter(name='HHHH')
def timedelta_format(value):
    assert type(value) == timedelta, 'This Filter only works with timedelta objects'
    return mark_safe("%.2f" % (value.total_seconds() / 3600.))

@register.filter(name='SSSSSSSSSS')
def datetime_format1(value):
    assert type(value) == datetime, 'This Filter only works with datetime objects'
    return mark_safe(str(value.strftime('%s')))
